Changelog
=========

Version 0.1
-----------

- Initial version.

Version 0.2
-----------

- Spelling Fixes
- Added RestComponentPermission with same arguments as the rest framework permissions
- Updated Documentation
